########################################
Minesoft PatBase REST API client CHANGES
########################################


development
===========

2018-06-12 0.1.0
================
- Persistently store user credentials for convenient usage with subsequent API operations
- Add basic implementation of PatBase API methods "query" and "searchresults"
- Improve tooling

2018-06-11 0.0.0
================
- Add project skeleton
- Add PatBase client skeleton with "login" method
